#include "project.h"
#include "stdio.h"

uint16_t next_compare[2] = { 2, 6 } ;
volatile int next_index = 0 ;

#define STR_LEN 64
char str[STR_LEN+1] ;
void    print(char *str)
{
    UART_UartPutString(str) ;
}

void cls(void)
{
    print("\033c") ; /* reset */
    CyDelay(20) ;
    print("\033[2J") ; /* clear screen */
    CyDelay(20) ;
}

void splash(char *title)
{
    cls() ;
    if (title && *title) {
        print(title) ;
        print(" ") ;
    } 
    snprintf(str, STR_LEN, "(%s %s)\n\r", __DATE__, __TIME__) ;
    print(str) ;
}

CY_ISR(pwm_isr)
{
    Control_Reg_Write(1) ;
    CyDelay(2) ;
    Control_Reg_Write(0) ;
    PWM_ClearInterrupt(PWM_INTR_MASK_TC) ;
}

void init_hardware(void)
{
    CyGlobalIntEnable; /* Enable global interrupts. */    
    UART_Start() ;
    splash("PSoC 4 PWM compare swap test") ;
    
    Control_Reg_Write(0) ;
    
    isr_1_StartEx(pwm_isr) ;

    PWM_Start() ;
}

void report(void)
{
    uint16_t compare, compare_buf ;
    uint16_t period, period_buf ;

    period =      PWM_ReadPeriod() ;
    period_buf =  PWM_ReadPeriodBuf() ;
    compare =     PWM_ReadCompare() ;
    compare_buf = PWM_ReadCompareBuf() ;
    snprintf(str, STR_LEN, "Period: %d (%d) Compare: %d (%d)\n\r",
        period, period_buf, compare, compare_buf) ;
    print(str) ;
    CyDelay(10) ;
}

int main(void)
{
    uint16_t prev_compare ;
    uint16_t compare ;
    
    init_hardware() ;
    
    prev_compare = PWM_ReadCompare() ;
    compare = prev_compare ;

    report() ;
            
    for(;;)
    {
        compare = PWM_ReadCompare() ;
        if (compare != prev_compare) {
            report() ;
            prev_compare = compare ;   
        }
        CyDelay(100) ;
    }
}
